# A simple visualization tool for ISO XML taskdata files

This project provides a basic plotting functionality for plotting the content of ISO BUS XML files as described in ISO 11783-10

## How to use it

```bash
python -m "isoxmlviz" -file TASKDATA.xml 
```

----

[packaging guide]: https://packaging.python.org
[distribution tutorial]: https://packaging.python.org/tutorials/packaging-projects/
[src]: https://github.com/lausdahl/isoxmlviz
[rst]: http://docutils.sourceforge.net/rst.html
[md]: https://tools.ietf.org/html/rfc7764#section-3.5 "CommonMark variant"
[md use]: https://packaging.python.org/specifications/core-metadata/#description-content-type-optional